@@ -1,5 +1,5 @@
 /* You may find the license in the LICENSE file */
- 
+
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
@@ -258,7 +258,8 @@ LimitedDict.prototype = {
 		if (this._arr.length == this._limit) {
 			delete this._dict[this._arr.shift()];
 		}
-		this._arr.push(this._dict[key] = value);
+		this._dict[key] = value;
+		this._arr.push(key);
 	}
 };
 
@@ -303,6 +304,7 @@ ContentHandling.prototype = {
 	_init: function ct__init() {
 		Observers.addObserver(this, 'xpcom-shutdown', false);
 		Observers.addObserver(this, 'private-browsing', false);
+		Observers.addObserver(this, 'http-on-modify-request', false);
 		this._prefs = Cc['@mozilla.org/preferences-service;1'].getService(Ci.nsIPrefBranch2);
 		this._prefs.addObserver(PREF_SNIFFVIDEOS, this, false);
 
@@ -314,8 +316,8 @@ ContentHandling.prototype = {
 		}
 	},
 	get _io() {
-    delete ContentHandling.prototype._io;
-    return (ContentHandling.prototype._io = Cc['@mozilla.org/network/io-service;1'].getService(Ci.nsIIOService));
+		delete ContentHandling.prototype._io;
+		return (ContentHandling.prototype._io = Cc['@mozilla.org/network/io-service;1'].getService(Ci.nsIIOService));
 	},
 
 	_uninit: function ct__uninit() {
@@ -327,14 +329,13 @@ ContentHandling.prototype = {
 
 		Observers.removeObserver(this, 'xpcom-shutdown');
 		Observers.removeObserver(this, 'private-browsing');
+		Observers.removeObserver(this, 'http-on-modify-request');
 	},
 	registerHttpObservers: function ct_registerHttpObservers() {
-		Observers.addObserver(this, 'http-on-modify-request', false);
 		Observers.addObserver(this, 'http-on-examine-response', false);
 		Observers.addObserver(this, 'http-on-examine-cached-response', false);
 	},
 	unregisterHttpObservers: function ct_unregisterHttpObservers() {
-		Observers.removeObserver(this, 'http-on-modify-request');
 		Observers.removeObserver(this, 'http-on-examine-response');
 		Observers.removeObserver(this, 'http-on-examine-cached-response');
 	},
@@ -353,7 +354,7 @@ ContentHandling.prototype = {
 		case 'nsPref:changed':
 			try {
 				let newValue = this._prefs.getBoolPref(PREF_SNIFFVIDEOS);
-				let differs = newValue == this.sniffVideos;
+				let differs = newValue != this.sniffVideos;
 				this.sniffVideos = newValue;
 				if (differs) {
 					if (newValue) {
@@ -419,7 +420,7 @@ ContentHandling.prototype = {
 			ss.seek(0, op);
 
 			if (post) {
-				this._data.setKey(channel.URI.spec, data);
+				this._data.setKey(channel.URI.spec, post);
 			}
 		}
 		catch (ex) {
@@ -561,27 +562,27 @@ AboutModule.prototype = {
 	
 	QueryInterface: XPCOMUtils.generateQI([Ci.nsIAboutModule]),
 	
-  newChannel : function(aURI) {
+	newChannel : function(aURI) {
 		try {
-		    let io = Cc['@mozilla.org/network/io-service;1'].getService(Ci.nsIIOService);
-		    let sec = Cc['@mozilla.org/scriptsecuritymanager;1'].getService(Ci.nsIScriptSecurityManager);
+				let io = Cc['@mozilla.org/network/io-service;1'].getService(Ci.nsIIOService);
+				let sec = Cc['@mozilla.org/scriptsecuritymanager;1'].getService(Ci.nsIScriptSecurityManager);
 
-	    	module('resource://dta/version.jsm');
-	    	if (!Version.ready) {
-	    		throw new Exception("Cannot build about:downthemall, version.jsm not ready");
-	    	}
+				module('resource://dta/version.jsm');
+				if (!Version.ready) {
+					throw new Exception("Cannot build about:downthemall, version.jsm not ready");
+				}
 
-		    let ru = ABOUT_URI.replace(
-		    	/%(.+?)%/g,
-		    	function (m, m1) (m1 in Version) ? Version[m1] : m
-		    );
-		    
-		    let uri = io.newURI(ru, null, null);
-		    let chan = io.newChannelFromURI(uri);
-		    chan.originalURI = aURI;
-		    chan.owner = sec.getCodebasePrincipal(uri);
-		    
-		    return chan;
+				let ru = ABOUT_URI.replace(
+					/%(.+?)%/g,
+					function (m, m1) (m1 in Version) ? Version[m1] : m
+				);
+				
+				let uri = io.newURI(ru, null, null);
+				let chan = io.newChannelFromURI(uri);
+				chan.originalURI = aURI;
+				chan.owner = sec.getCodebasePrincipal(uri);
+				
+				return chan;
 		}
 		catch (ex) {
 			log(ex);
@@ -1060,8 +1061,8 @@ FilterManager.prototype = {
 };
 
 if (XPCOMUtils.generateNSGetFactory) {
-    var NSGetFactory = XPCOMUtils.generateNSGetFactory([Stuff, ContentHandling, AboutModule, FilterManager]);
+		var NSGetFactory = XPCOMUtils.generateNSGetFactory([Stuff, ContentHandling, AboutModule, FilterManager]);
 }
 else {
-    function NSGetModule() XPCOMUtils.generateModule([Stuff, ContentHandling, AboutModule, FilterManager]);
+		function NSGetModule() XPCOMUtils.generateModule([Stuff, ContentHandling, AboutModule, FilterManager]);
 }
\ No newline at end of file
